@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: libraries.lisp 11087 2006-09-03 02:31:58Z kevin $
+;;;; $Id: libraries.lisp 11764 2007-07-22 19:09:39Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
@@ -80,23 +80,27 @@ library type if type is not specified."
   #+(or cmu scl) (declare (ignore module))
   #+lispworks (declare (ignore supporting-libraries))
 
-  (when (and filename (or (null (pathname-directory filename))
-                          (probe-file filename)))
-    (if (pathnamep filename)    ;; ensure filename is a string to check if already loaded
-	(setq filename (namestring (if (null (pathname-directory filename))
-				       filename
-				       ;; lispworks treats as UNC, so use truename
-				       #+(and lispworks win32) (truename filename)
-				       #-(and lispworks win32) filename))))
+  (flet ((load-failure ()
+           (error "Unable to load foreign library \"~A\"." filename)))
+    (when (and filename (or (null (pathname-directory filename))
+                            (probe-file filename)))
+      (if (pathnamep filename)    ;; ensure filename is a string to check if already loaded
+          (setq filename (namestring (if (null (pathname-directory filename))
+                                         filename
+                                         ;; lispworks treats as UNC, so use truename
+                                         #+(and lispworks win32) (truename filename)
+                                         #-(and lispworks win32) filename))))
 
-    (if (and (not force-load)
-	     (find filename *loaded-libraries* :test #'string-equal))
-	t ;; return T, but don't reload library
+      (if (and (not force-load)
+               (find filename *loaded-libraries* :test #'string-equal))
+          t ;; return T, but don't reload library
       (progn
 	#+cmu
 	(let ((type (pathname-type (parse-namestring filename))))
 	  (if (string-equal type "so")
-	      (sys::load-object-file filename)
+	      (unless
+                  (sys::load-object-file filename)
+                (load-failure))
 	      (alien:load-foreign filename
 				  :libraries
 				  (convert-supporting-libraries-to-string
@@ -115,13 +119,13 @@ library type if type is not specified."
 		(error c))))
 
 	#+lispworks (fli:register-module module :real-name filename
-                                                :connection-style :immediate)
+                                         :connection-style :immediate)
 	#+allegro (load filename)
 	#+openmcl (ccl:open-shared-library filename)
 	#+digitool (ccl:add-to-shared-library-search-path filename t)
 
 	(push filename *loaded-libraries*)
-	t))))
+	t)))))
 
 (defun convert-supporting-libraries-to-string (libs)
   (let (lib-load-list)
