@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg/John Desoi
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: readmacros-mcl.lisp 10608 2005-07-01 00:39:48Z kevin $
+;;;; $Id: readmacros-mcl.lisp 10917 2006-04-18 00:07:09Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
@@ -17,11 +17,11 @@
 
 
 ;; trap macros don't work right directly in the macros
-#+(and mcl (not openmcl))
+#+digitool
 (defun new-ptr (size)
   (#_NewPtr size))
 
-#+(and mcl (not openmcl))
+#+digitool
 (defun dispose-ptr (ptr)
   (#_DisposePtr ptr))
 
